@@ -1,5 +1,3 @@
-import datetime
-
 from sqlalchemy.orm import Session
 
 from dagops.state import models
@@ -15,20 +13,15 @@ class TaskCRUD(CRUD):
         db: Session,
         task: TaskCreate,
     ) -> models.Task:
-        now = datetime.datetime.now()
         task_dict = task.dict()
-        upstream = self.read_by_field_isin(db, 'id', task_dict['upstream'], not_found_ok=False)
+        upstream = self.read_by_field_isin(db, 'id', task_dict['upstream'], not_found_error=True)
         task_dict['upstream'] = upstream
         worker, = worker_crud.read_by_field(db, 'name', task_dict.pop('worker_name'))
         task_dict['worker'] = worker
-        # print(task_dict)
         db_task = models.Task(
             **task_dict,
-            created_at=now,
-            updated_at=now,
             status=TaskStatus.PENDING,
         )
-
         db.add(db_task)
         db.commit()
         db.refresh(db_task)
